@@ -375,7 +375,7 @@ import re
 
 from abc import ABC, abstractmethod
 from copy import deepcopy
-from typing import Any, Callable, Dict, List, Optional, Tuple, Type
+from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
 
 from ae.base import (                                                                                   # type: ignore
     CFG_EXT, INI_EXT, NAME_PARTS_SEP, UNSET, instantiate_config_parser, norm_name, now_str, os_platform, snake_to_camel)
@@ -391,7 +391,7 @@ from ae.core import DEBUG_LEVELS, registered_app_names
 from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.2.78'
+__version__ = '0.2.79'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -1491,6 +1491,48 @@ class MainAppBase(ConsoleApp, ABC):
         wid_visible = self.widget_visible
         return [chi for chi in getattr(wid, 'container', wid).children if not only_visible or wid_visible(chi)]
 
+    @staticmethod
+    def widget_pos(wid) -> Tuple[float, float]:
+        """ return the absolute window x and y position of the passed widget.
+
+        :param wid:             widget to determine the position of.
+        :return:                tuple of x and y screen coordinate.
+        """
+        return wid.pos
+
+    def widgets_enclosing_rectangle(self, widgets: Union[list, tuple]) -> Tuple[float, float, float, float]:
+        """ calculate the minimum bounding rectangle all the passed widgets.
+
+        :param widgets:         list/tuple of widgets to determine the minimum bounding rectangle for.
+        :return:                tuple of floats with the x, y, width, height values of the bounding rectangle.
+        """
+        min_x = min_y = 999999.9
+        max_x = max_y = 0.0
+
+        for wid in widgets:
+            w_x, w_y = self.widget_pos(wid)
+            if w_x < min_x:
+                min_x = w_x
+            if w_y < min_y:
+                min_y = w_y
+
+            w_w, w_h = self.widget_size(wid)
+            if w_x + w_w > max_x:
+                max_x = w_x + w_w
+            if w_y + w_h > max_y:
+                max_y = w_y + w_h
+
+        return min_x, min_y, max_x - min_x, max_y - min_y
+
+    @staticmethod
+    def widget_size(wid) -> Tuple[float, float]:
+        """ return the size (width and height) in pixels of the passed widget.
+
+        :param wid:             widget to determine the size of.
+        :return:                tuple of width and height in pixels.
+        """
+        return wid.size
+
     @staticmethod
     def widget_visible(wid: Any) -> bool:
         """ determine if the passed widget is visible (has width and height and (visibility or opacity) set).
